# (IMPORTS-START) - DO NOT DELETE THIS LINE!
import logging

from fastapi import APIRouter, Depends, Request
from pysura.faster_api.security import PysuraSecurity, PysuraProvider, Provider
from pysura.faster_api.enums import ApiResponse, ClientRole
from generated_types import *

# (IMPORTS-END) - DO NOT DELETE THIS LINE!

ROUTE = "/action_mutation_pong/"
ALLOWED_ROLES = [  # The roles allowed to call this action
    ClientRole.admin.name, ClientRole.user.name
]
action_mutation_pong_router = APIRouter(
    tags=["action_mutation_pong"]
)


@action_mutation_pong_router.post(ROUTE,
                                  dependencies=[
                                      Depends(PysuraSecurity(
                                          require_jwt=True,
                                          require_event_secret=True,
                                          allowed_roles=ALLOWED_ROLES
                                      ))
                                  ],
                                  response_model=ActionMutationPongOutput
                                  )
async def action_mutation_pong(_: Request,
                               action_mutation_pong_input: ActionMutationPongInput | None = None,
                               provider: Provider | None = Depends(PysuraProvider(
                                   # (DEPENDENCY-INJECTION-START) - DO NOT DELETE THIS LINE!
                                   provide_identity=True,
                                   provide_firebase=True,
                                   provide_graphql=True,
                                   provide_storage=True,
                                   provide_sql=True
                                   # (DEPENDENCY-INJECTION-END) - DO NOT DELETE THIS LINE!
                               ))):
    # (BUSINESS-LOGIC-START) - DO NOT DELETE THIS LINE!
    user_id = provider.user_identity.user_id
    provider.graphql.execute(
        query="""mutation Pong($user_id: String = "", $message: String = "", $number: Int = 10) {
  update_public_user_by_pk(pk_columns: {user_id: $user_id}, _set: {message: $message, number: $number}) {
    user_id
  }
}""",
        variables={
            "user_id": user_id,
            "message": action_mutation_pong_input.message,
            "number": action_mutation_pong_input.number
        }
    )
    response = ActionMutationPongOutput(
        data=ActionMutationPongOutputData(
            message=action_mutation_pong_input.message,
            number=action_mutation_pong_input.number
        ),
        nodes=None,
        response_name=ApiResponse.SUCCESS.name,
        response_value=ApiResponse.SUCCESS.value
    ).dict()
    return response
    # (BUSINESS-LOGIC-END) - DO NOT DELETE THIS LINE!



# (IMPORTS-START) - DO NOT DELETE THIS LINE!
import logging

from fastapi import APIRouter, Depends, Request, Body, Response
from pysura.faster_api.security import PysuraSecurity, PysuraProvider, Provider

# (IMPORTS-END) - DO NOT DELETE THIS LINE!

ROUTE = "/SNAKE/"
SNAKE_router = APIRouter(
    tags=["SNAKE"]
)


@SNAKE_router.post(ROUTE, dependencies=[Depends(PysuraSecurity(require_jwt=False, require_event_secret=True))])
async def SNAKE(_: Request,
                provider: Provider | None = Depends(
                    PysuraProvider(
                        # (DEPENDENCY-INJECTION-START) - DO NOT DELETE THIS LINE!
                        provide_identity=False,
                        provide_firebase=True,
                        provide_graphql=True,
                        provide_storage=True,
                        provide_sql=True
                        # (DEPENDENCY-INJECTION-END) - DO NOT DELETE THIS LINE!
                    )
                ),
                data=Body(...)):
    # (BUSINESS-LOGIC-START) - DO NOT DELETE THIS LINE!
    logging.log(logging.INFO, data)
    logging.log(logging.INFO, provider)
    return Response(status_code=200)
    # (BUSINESS-LOGIC-END) - DO NOT DELETE THIS LINE!



# (IMPORTS-START) - DO NOT DELETE THIS LINE!
import logging

from fastapi import APIRouter, Depends, Request, Body, Response
from pysura.faster_api.security import PysuraSecurity, PysuraProvider, Provider
from pysura.faster_api.models import Event

# (IMPORTS-END) - DO NOT DELETE THIS LINE!

ROUTE = "/event_update_user_cascade/"
event_update_user_cascade_router = APIRouter(
    tags=["event_update_user_cascade"]
)


@event_update_user_cascade_router.post(ROUTE, dependencies=[
    Depends(PysuraSecurity(require_jwt=False, require_event_secret=True))])
async def event_update_user_cascade(_: Request,
                                    provider: Provider | None = Depends(
                                        PysuraProvider(
                                            # (DEPENDENCY-INJECTION-START) - DO NOT DELETE THIS LINE!
                                            provide_identity=False,
                                            provide_firebase=True,
                                            provide_graphql=True,
                                            provide_storage=True,
                                            provide_sql=True
                                            # (DEPENDENCY-INJECTION-END) - DO NOT DELETE THIS LINE!
                                        )
                                    ),
                                    data: Event = Body(...)):
    # (BUSINESS-LOGIC-START) - DO NOT DELETE THIS LINE!
    if data.event.op != "INSERT":
        return Response(status_code=200)
    new_data = data.event.data.new
    user_id = new_data["user_id"]
    provider.graphql.execute(
        query="""mutation PublicUserCascade($user_id: String = "") {
  insert_public_user_one(object: {user_id: $user_id}) {
    user_id
  }
}""",
        variables={
            "user_id": user_id
        }
    )
    return Response(status_code=200)
    # (BUSINESS-LOGIC-END) - DO NOT DELETE THIS LINE!



# (IMPORTS-START) - DO NOT DELETE THIS LINE!
import logging

from fastapi import APIRouter, Depends, Request
from pysura.faster_api.security import PysuraSecurity, PysuraProvider, Provider
from pysura.faster_api.enums import ApiResponse, ClientRole
from generated_types import *

# (IMPORTS-END) - DO NOT DELETE THIS LINE!

ROUTE = "/action_query_ping/"
ALLOWED_ROLES = [  # The roles allowed to call this action
    ClientRole.admin.name, ClientRole.user.name
]
action_query_ping_router = APIRouter(
    tags=["action_query_ping"]
)


@action_query_ping_router.post(ROUTE,
                               dependencies=[
                                   Depends(PysuraSecurity(
                                       require_jwt=True,
                                       require_event_secret=True,
                                       allowed_roles=ALLOWED_ROLES
                                   ))
                               ],
                               response_model=ActionQueryPingOutput
                               )
async def action_query_ping(_: Request,
                            action_query_ping_input: ActionQueryPingInput | None = None,
                            provider: Provider | None = Depends(PysuraProvider(
                                # (DEPENDENCY-INJECTION-START) - DO NOT DELETE THIS LINE!
                                provide_identity=True,
                                provide_firebase=True,
                                provide_graphql=True,
                                provide_storage=True,
                                provide_sql=True
                                # (DEPENDENCY-INJECTION-END) - DO NOT DELETE THIS LINE!
                            ))):
    # (BUSINESS-LOGIC-START) - DO NOT DELETE THIS LINE!
    user_id = provider.user_identity.user_id
    response = provider.graphql.execute(
        query="""query Ping($user_id: String = "") {
  public_user_by_pk(user_id: $user_id) {
    message
    number
  }
}""",
        variables={
            "user_id": user_id
        }
    )
    data = response["data"]["public_user_by_pk"]

    response = ActionQueryPingOutput(
        data=ActionQueryPingOutputData(
            **data
        ),
        nodes=None,
        response_name=ApiResponse.SUCCESS.name,
        response_value=ApiResponse.SUCCESS.value
    ).dict()
    return response
    # (BUSINESS-LOGIC-END) - DO NOT DELETE THIS LINE!
